@@ -10,12 +10,14 @@ import sop.exception.SOPGPException;
 import sop.external.ExternalSOP;
 import sop.operation.Armor;
 
-import java.io.IOException;
 import java.io.InputStream;
 import java.util.ArrayList;
-import java.util.Properties;
 import java.util.List;
+import java.util.Properties;
 
+/**
+ * Implementation of the {@link Armor} operation using an external SOP binary.
+ */
 public class ArmorExternal implements Armor {
 
     private final List<String> commandList = new ArrayList<>();
@@ -34,7 +36,7 @@ public class ArmorExternal implements Armor {
     }
 
     @Override
-    public Ready data(InputStream data) throws SOPGPException.BadData, IOException {
-        return ExternalSOP.ready(Runtime.getRuntime(), commandList, envList, data);
+    public Ready data(InputStream data) throws SOPGPException.BadData {
+        return ExternalSOP.executeTransformingOperation(Runtime.getRuntime(), commandList, envList, data);
     }
 }
