@@ -14,6 +14,9 @@ import java.util.ArrayList;
 import java.util.List;
 import java.util.Properties;
 
+/**
+ * Implementation of the {@link ExtractCert} operation using an external SOP binary.
+ */
 public class ExtractCertExternal implements ExtractCert {
 
     private final List<String> commandList = new ArrayList<>();
@@ -33,6 +36,6 @@ public class ExtractCertExternal implements ExtractCert {
 
     @Override
     public Ready key(InputStream keyInputStream) throws SOPGPException.BadData {
-        return ExternalSOP.ready(Runtime.getRuntime(), commandList, envList, keyInputStream);
+        return ExternalSOP.executeTransformingOperation(Runtime.getRuntime(), commandList, envList, keyInputStream);
     }
 }
